@@ -1,4 +1,3 @@
-#!/usr/bin/python3
 # SPDX-License-Identifier: MIT
 
 from datetime import timedelta
@@ -48,6 +47,19 @@ class RtcAlarmWrong(S0i3Failure):
         self.url = "https://github.com/systemd/systemd/issues/24279"
 
 
+class MissingGpu(S0i3Failure):
+    """GPU device is missing"""
+
+    def __init__(self):
+        super().__init__()
+        self.description = "GPU device is missing"
+        self.explanation = (
+            "Running the s2idle sequence without an integrated GPU is likely "
+            "to cause problems. If you have a mux in BIOS, enable the integrated "
+            "GPU."
+        )
+
+
 class MissingAmdgpu(S0i3Failure):
     """AMDGPU driver is missing"""
 
@@ -142,7 +154,7 @@ class MissingDriver(S0i3Failure):
         self.description = f"{slot} driver is missing"
         self.explanation = (
             f"No driver has been bound to PCI device {slot} "
-            "Without a driver, the hardware may be able to enter a low power. "
+            "Without a driver, the hardware may be able to enter a low power "
             "state, but there may be spurious wake up events."
         )
 
@@ -467,7 +479,7 @@ class MissingIommuACPI(S0i3Failure):
         super().__init__()
         self.description = f"Device {device} missing from ACPI tables"
         self.explanation = (
-            "The ACPI device {device} is required for suspend to work when the IOMMU is enabled. "
+            f"The ACPI device {device} is required for suspend to work when the IOMMU is enabled. "
             "Please check your BIOS settings and if configured correctly, report a bug to your system vendor."
         )
         self.url = "https://gitlab.freedesktop.org/drm/amd/-/issues/3738#note_2667140"
@@ -564,6 +576,15 @@ class LimitedCores(S0i3Failure):
         )
 
 
+class CpuTopologyUnknown(S0i3Failure):
+    """CPU topology unknown"""
+
+    def __init__(self):
+        super().__init__()
+        self.description = "CPU topology unknown"
+        self.explanation = "The CPU topology could not be determined. This may prevent the system from entering hardware sleep states correctly."
+
+
 class RogAllyOldMcu(S0i3Failure):
     """MCU firwmare is too old"""
 
